@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2024 Antonio Diaz Diaz.
+   Copyright (C) 2005-2025 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -58,7 +58,7 @@ bool Basic_buffer::add_line( const char * const buf, const int len )
   {
   data.back().append( buf, len );
   if( data.back().size() > LONG_MAX / 2 ) return false;
-  if( data.back().size() && data.back()[data.back().size()-1] == '\n' )
+  if( data.back().size() && data.back().end()[-1] == '\n' )
     {
     if( data.size() >= data.capacity() && data.size() >= 1000 )
       data.reserve( data.size() + ( data.size() / 10 ) );
