@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2024 Antonio Diaz Diaz.
+   Copyright (C) 2005-2025 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -79,9 +79,7 @@ bool Block::valid()
 
 
 void Block::save_block_position()
-  {
-  saved_bufferp = bufferp_; saved_begin = begin_; saved_end = end_;
-  }
+  { saved_bufferp = bufferp_; saved_begin = begin_; saved_end = end_; }
 
 
 void Block::restore_block_position()
@@ -94,15 +92,13 @@ void Block::restore_block_position()
 
 
 void Block::reset()
-  {
-  bufferp_ = 0; begin_ = end_ = Point(); disable_marking();
-  }
+  { bufferp_ = 0; begin_ = end_ = Point(); disable_marking(); }
+
+void Block::unmark() { end_ = begin_; disable_marking(); }
 
 
 void Block::set_block( Buffer & buffer, const Point & p1, const Point & p2 )
-  {
-  bufferp_ = &buffer; begin_ = p1; end_ = p2; disable_marking();
-  }
+  { bufferp_ = &buffer; begin_ = p1; end_ = p2; disable_marking(); }
 
 
 void Block::set_begin( Buffer & buffer, const Point & p )
@@ -215,8 +211,7 @@ bool Block::copy_block( Buffer & buffer, const Point & p, const bool move )
     }
   buffer.reset_appendable();
   if( done )
-    { if( RC::editor_options().auto_unmark ) reset();
-      else set_block( buffer, p, p_end ); }
+    set_block( buffer, p, RC::editor_options().auto_unmark ? p : p_end );
   return done;
   }
 
