@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2024 Antonio Diaz Diaz.
+   Copyright (C) 2005-2025 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -84,6 +84,45 @@ void adjust_marks_and_pointers( Buffer & b, const Point & p1,
       adjust_point( b, *pv[i], p1, p2_old, p2_new );
   }
 
+
+/* Return the number of bytes really written.
+   If (value returned < size), it is always an error.
+*/
+long fwriteblock( const char * const buf, const long size, FILE * const f )
+  {
+  long sz = 0;
+  errno = 0;
+  while( sz < size )
+    {
+    const long n = std::fwrite( buf + sz, 1, size - sz, f );
+    if( n > 0 ) sz += n;
+    else if( errno != EINTR ) break;
+    errno = 0;
+    }
+  return sz;
+  }
+
+
+bool write_to_file( const std::vector< std::string > & data,
+                    const Point & p1, const Point & p2, FILE * const f )
+  {
+  if( p1 >= p2 ) return true;			// nothing to write
+  long line = p1.line;
+  if( line == p2.line )
+    { const long size = p2.col - p1.col;
+      return fwriteblock( data[line].c_str() + p1.col, size, f ) == size; }
+  long size = data[line].size() - p1.col;
+  if( fwriteblock( data[line].c_str() + p1.col, size, f ) != size )
+    return false;
+  while( ++line < p2.line )
+    if( fwriteblock( data[line].c_str(), data[line].size(), f ) !=
+        (long)data[line].size() ) return false;
+  size = p2.col;
+  if( size && fwriteblock( data[line].c_str(), size, f ) != size )
+    return false;
+  return true;
+  }
+
 } // end namespace
 
 
@@ -209,7 +248,7 @@ Buffer::Buffer( const char * const namep, const bool read_only )
   if( isatty( fileno( f ) ) )
     { std::fclose( f ); throw Error( "Is a terminal" ); }
 
-  const int bufsize = 65536;
+  enum { bufsize = 65536 };
   char buf[bufsize];
   bool aborted = false;
   const bool interactive = Screen::height() > 0;
@@ -333,7 +372,7 @@ bool Buffer::save( const std::string * namep, bool save_to,
       std::rename( namep->c_str(), backname.c_str() );
       backuped = true;
       }
-    else std::remove( namep->c_str() );
+    else std::remove( namep->c_str() );		// avoid following links
     }
 
   FILE * f = std::fopen( namep->c_str(), append ? "a" : "w" );
@@ -343,16 +382,18 @@ bool Buffer::save( const std::string * namep, bool save_to,
 
   if( !this->pisvalid( p1 ) ) p1 = this->bof();
   if( !this->pisvalid( p2 ) ) p2 = this->eof();
+  bool error = false;
   if( !crlf )
-    for( Point p = p1; p < p2; ) { std::fputc( pgetc( p ), f ); }
+    error = !write_to_file( get_data(), p1, p2, f );
   else for( Point p = p1; p < p2; )	// put a CR before each LF
     {
     const int ch = pgetc( p );
-    if( ch == '\n' ) std::fputc( '\r', f );
-    std::fputc( ch, f );
+    if( ch == '\n' && std::fputc( '\r', f ) != '\r' ) error = true;
+    if( std::fputc( ch, f ) != ch ) error = true;
     }
-  if( std::fclose( f ) != 0 )
-    { if( !had_name ) { name_.clear(); } throw Error( "Error closing file" ); }
+  if( std::fclose( f ) != 0 || error )
+    { if( !had_name ) name_.clear();
+      throw Error( error ? "Error writing file" : "Error closing file" ); }
   if( !save_to )
     {
     for( long i = change_history.records() - 1; i >= 0; --i )
@@ -590,7 +631,7 @@ bool Buffer::redo( Point & p )
     atom.bbp = tmp;
     adjust_marks_and_pointers( *this, atom.begin, end, atom.end, &atom.end );
     }
-  p = rec.after;
+  p = rec.after;				// don't use rec.before here
   std::swap( modified_, rec.modified );
   return true;
   }
