@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2024 Antonio Diaz Diaz.
+   Copyright (C) 2005-2025 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -119,7 +119,7 @@ const char * Bufhandle_vector::save_all_named()
     }
   Screen::show_status_lines();
   int bufsize = 0;
-  char * const buf = Screen::line_buf( &bufsize );
+  char * const buf = Screen::msg_line_buf( &bufsize );
   snprintf( buf, bufsize, "%s%d named buffer%s saved",
             done ? "" : "Only ", count, ( count == 1 ) ? "" : "s" );
   return buf;
@@ -142,7 +142,7 @@ const char * Bufhandle_vector::show_status()
   Screen::show_status_lines();
   if( bcount == 1 ) return "** This is the only buffer being edited **";
   int bufsize = 0;
-  char * const buf = Screen::line_buf( &bufsize );
+  char * const buf = Screen::msg_line_buf( &bufsize );
   snprintf( buf, bufsize,
             "**  %d modified and  %d unnamed out of  %d total buffers **",
             mcount, ucount, bcount );
