@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2024 Antonio Diaz Diaz.
+   Copyright (C) 2005-2025 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -736,12 +736,17 @@ int map_to_byte( const int code )
     case 0x209B: return 's';	// latin subscript small letter s
     case 0x209C: return 't';	// latin subscript small letter t
     case 0x20AC: return 0xA4;	// euro sign
+    case 0x2112: return 'L';	// script capital l
+    case 0x2113: return 'l';	// script small l
     case 0x212A: return 'K';	// Kelvin sign
     case 0x212B: return 0xC5;	// Angstrom sign
     case 0x2191: return '^';	// upwards arrow
     case 0x2193: return 'V';	// downwards arrow
     case 0x21D1: return '^';	// upwards double arrow
     case 0x21D3: return 'V';	// downwards double arrow
+    case 0x2208: return 'E';	// element of
+    case 0x220A: return 'e';	// small element of
+    case 0x220F: return 'P';	// N-ary product
     case 0x2211: return 'S';	// N-ary summation
     case 0x2212: return '-';	// minus sign
     case 0x2213: return 0xB1;	// minus-or-plus sign
@@ -753,11 +758,16 @@ int map_to_byte( const int code )
     case 0x2223: return '|';	// divides
     case 0x2236: return ':';	// ratio
     case 0x223C: return '~';	// tilde operator
+    case 0x2243:		// asymptotically equal to
+    case 0x2245:		// approximately equal to
+    case 0x2248:		// almost equal to
     case 0x2261: return '=';	// identical to
     case 0x227A: return '<';	// precedes
     case 0x227B: return '>';	// succeeds
     case 0x22B0: return '<';	// precedes under relation
     case 0x22B1: return '>';	// succeeds under relation
+    case 0x222A:		// union
+    case 0x22C3: return 'U';	// n-ary union
     case 0x22C5: return 0xB7;	// dot operator
     case 0x23AF: return '-';	// horizontal line extension
     case 0x2500:		// box drawings light horizontal
@@ -879,8 +889,12 @@ const char * map_to_string( const int code )
     case 0x227C: return "<=";	// precedes or equal to
     case 0x227D: return ">=";	// succeeds or equal to
     case 0x22A3: return "-|";	// left tack
+    case 0x22EE:		// vertical ellipsis
+    case 0x22EF: return "";	// midline horizontal ellipsis
+    case 0x230A: return "|_";	// left floor
+    case 0x230B: return "_|";	// right floor
     case 0x2639: return ":-(";	// white frowning face
-    case 0x263A: return ":-)";	// white smiling face
+    case 0x263A:		// white smiling face
     case 0x263B: return ":-)";	// black smiling face
     // alphabetic presentation forms
     case 0xFB00: return "ff";	// latin small ligature ff
@@ -1204,8 +1218,9 @@ int Encoding::utf8_decode( const std::string & in, std::string & out,
     const int ch = map_to_byte( code );
     if( ch >= 0 ) { if( ch < 256 ) { out += ch; } i += len; continue; }
     const char * const str = map_to_string( code );
+    // separate fraction 1/4, 1/2, or 3/4 from preceding digit
     if( str && code >= 0xBC && code <= 0xBE && !out.empty() &&
-        std::isdigit( (unsigned char)out[out.size()-1] ) ) out += ' ';
+        std::isdigit( (unsigned char)out.end()[-1] ) ) out += ' ';
     if( str ) out += str;
     else if( force ) out.append( in, i, len );
     else { if( idxp ) { *idxp = i; } return code; }
