@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2024 Antonio Diaz Diaz.
+   Copyright (C) 2005-2025 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -43,7 +43,7 @@ namespace {
 
 const char * const     program_name = "moe";
 const char * const config_file_name = "moe.conf";
-const char * const     program_year = "2024";
+const char * const     program_year = "2025";
 const char * invocation_name = program_name;		// default value
 
 
@@ -64,7 +64,7 @@ void show_help()
                "\nUsage: %s [global_options] [[+[line[,col]]] file_name [file_options]]...\n",
                invocation_name );
   std::printf( "\n'global_options' are a mix of editor options and default 'file_options'.\n"
-               "Most long option names have a negative form '--backup' '--no-backup'.\n"
+               "Most long option names have a negative form: '--backup' '--no-backup'.\n"
                "\nEach file name may be preceded by '+[line[,column]]' to start the cursor\n"
                "at the line, and optionally column, specified. 'line' and 'column' are\n"
                "applied to subsequent files until new values are specified for them.\n"
@@ -74,7 +74,6 @@ void show_help()
                "\nEditor options:\n"
                "  -h, --help               display this help and exit\n"
                "  -V, --version            output version information and exit\n"
-//               "  -1, --orphan             put extra files in orphaned buffers\n"
                "  -b, --backup             create backup files (default)\n"
                "  -B, --no-backup          don't create backup files\n"
                "  -e, --exit-ask           make save-and-close ask always for confirmation\n"
