@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2024 Antonio Diaz Diaz.
+   Copyright (C) 2005-2025 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -87,7 +87,7 @@ void append_common_prefix( std::string & name,
 
 bool append_slash_if_dir( std::string & name )
   {
-  if( name.size() && name[name.size()-1] != '/' )
+  if( name.size() && name.end()[-1] != '/' )
     {
     struct stat st;
     if( stat( name.c_str(), &st ) == 0 && S_ISDIR( st.st_mode ) )
@@ -230,7 +230,7 @@ bool Menu::file_menu( const std::string & prompt, std::string & name )
 
   tilde_expansion( name );
   split_filename( name, dirname, basename );
-  if( basename.empty() || basename[basename.size()-1] != '*' ) basename += '*';
+  if( basename.empty() || basename.end()[-1] != '*' ) basename += '*';
 
   DIR * const dirp = opendir( dirname.size() ? dirname.c_str() : "." );
   if( !dirp && ( errno == ENOTDIR || errno == ENOENT ) ) return true;
@@ -350,7 +350,7 @@ int Menu::get_filename( const std::string & prompt, std::string & name,
 
 bool Menu::is_regular( const std::string & name, bool * can_readp )
   {
-  if( name.size() && name[name.size()-1] != '/' )
+  if( name.size() && name.end()[-1] != '/' )
     {
     struct stat st;
     const int i = stat( name.c_str(), &st );
