@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2024 Antonio Diaz Diaz.
+   Copyright (C) 2005-2025 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -92,8 +92,7 @@ enum Optcode
   {
   auto_unmark = 'u', backup = 'b', no_backup = 'B', /*beep = 'p',*/
   exit_ask = 'e', ignore_case = 'i', indent_step = 'n', keep_lines = 'k',
-  max_windows = 'm', orphan_extra= '1', rectangle_mode = 'x',
-  search_wrap = 's', smart_home = 'H',
+  max_windows = 'm', rectangle_mode = 'x', search_wrap = 's', smart_home = 'H',
   auto_indent = 'a', lmargin = 'l', rmargin = 'r', overwrite = 'O',
   read_only = 'o', two_spaces = '2', word_wrap = 'w', no_word_wrap = 'W',
   no_auto_unmark = 256, /*no_beep,*/ no_exit_ask, no_ignore_case,
@@ -118,7 +117,6 @@ const Arg_parser::Option options[] =
   { indent_step,       "indent-step",    Arg_parser::yes },
   { keep_lines,        "keep-lines",     Arg_parser::yes },
   { max_windows,       "max-windows",    Arg_parser::yes },
-  { orphan_extra,      "orphan",         Arg_parser::no  },
   { rectangle_mode,    "rectangle",      Arg_parser::no  },
   { no_rectangle_mode, "no-rectangle",   Arg_parser::no  },
   { search_wrap,       "search-wrap",    Arg_parser::no  },
@@ -137,6 +135,7 @@ const Arg_parser::Option options[] =
   { no_two_spaces,     "no-two-spaces",  Arg_parser::no  },
   { word_wrap,         "word-wrap",      Arg_parser::no  },
   { no_word_wrap,      "no-word-wrap",   Arg_parser::no  },
+  { '1',               "orphan",         Arg_parser::no  },	// ignored
   { 0,                 0,                Arg_parser::no  } };
 
 
@@ -197,7 +196,6 @@ bool set_option_from_code( const Arg_parser & parser, const int argind,
       if( !parse_int( arg, n ) ) errcode = 1;
       else if( !editor_options_.set_max_windows( n ) ) errcode = 2;
       break;
-    case orphan_extra:      editor_options_.orphan_extra = true; break;
     case rectangle_mode:    editor_options_.rectangle_mode = true; break;
     case no_rectangle_mode: editor_options_.rectangle_mode = false; break;
     case search_wrap:       editor_options_.search_wrap = true; break;
@@ -225,6 +223,7 @@ bool set_option_from_code( const Arg_parser & parser, const int argind,
       else if( !Buffer::Options().set_rmargin( n - 1 ) ) errcode = 2;
       else file_options.add_option( code, n - 1 );
       break;
+    case '1': break;		// ignored
     default: std::fprintf( stderr, "%sinternal error: uncaught option.\n", msg );
              return false;
     }
@@ -310,15 +309,15 @@ bool unwanted_name( const std::string & name )
   const char * const ext5[] = { "class", 0 };
   const char * const * ext[5] = { ext1, ext2, ext3, ext4, ext5 };
 
-  if( name == "." || name == ".." || name.empty() ||
-      name[name.size()-1] == '~' ) return true;
+  if( name == "." || name == ".." || name.empty() || name.end()[-1] == '~' )
+    return true;
   for( unsigned i = 0; i < 5; ++i )
     {
     if( name.size() <= i + 2 ) break;
     if( name[name.size()-i-2] != '.' ) continue;
     for( const char * const * p = ext[i]; *p; ++p )
       if( name.compare( name.size() - i - 1, i + 1, *p ) == 0 ) return true;
-    if( i == 0 && std::isdigit( (unsigned char)name[name.size()-1] ) )
+    if( i == 0 && std::isdigit( (unsigned char)name.end()[-1] ) )
       return true;		// exclude man pages *.[0-9]
     break;			// compare only one extension size
     }
@@ -333,7 +332,7 @@ bool add_handles_recursively( std::string name, const long line, const long col,
                               const File_options & file_options,
                               bool & first_post, bool & read_error_found )
   {
-  while( !name.empty() && name[name.size()-1] == '/' )
+  while( !name.empty() && name.end()[-1] == '/' )
     name.resize( name.size() - 1 );		// reject "/", "//", etc.
   if( name.empty() ) return false;
   while( name.size() > 2 && name[0] == '.' && name[1] == '/' )
@@ -483,7 +482,7 @@ int RC::process_rcfile( const std::string & name )
   const char delimiters[] = " \t\r\n";
   int retval = 0;
   int regex_status = 0;		// 1 = got regex name, 2 got regex option
-  const int bufsize = 1024;
+  enum { bufsize = 1024 };
   char buf[bufsize];
   for( int line = 1; ; ++line )
     {
