@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2024 Antonio Diaz Diaz.
+   Copyright (C) 2005-2025 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -61,7 +61,7 @@ public:
   bool compare_prev() const { return prev == current; }
   } last_key;
 
-char * line_buf_;
+char * msg_line_buf_, * status_line_buf_;
 int line_buf_size;
 int height_ = 0, width_ = 0;	// if > 0, init has been called
 int clock_limit;		//   0: disable clock
@@ -69,7 +69,6 @@ int clock_limit;		//   0: disable clock
 				// > 1: first line used by menu
 enum { clock_string_size = 5 };
 char clock_string_[clock_string_size+1] = " 0:00";
-bool blink = false;		// enable blinking dots in clock
 
 std::vector< Lines_and_cursor > lines_and_cursor_vector;
 
@@ -340,7 +339,6 @@ const char * control_s_loop( int key, const char * const version_msg )
     case '2':
     case '4':
     case '8': msg = w.show_multichar_value( key - '0', false ); break;
-    case 'B': blink = !blink; break;
     case 'C': RC::editor_options().show_code_lpos =
                 ( RC::editor_options().show_code_lpos == 1 ) ? 0 : 1;
               show_status_lines(); break;
@@ -495,7 +493,8 @@ bool Screen::init()
   if( height_ < 25 || width_ < 80 ) { endwin(); return false; }
   std::atexit( dummy_endwin );
   line_buf_size = width_ + 1;
-  line_buf_ = new char[line_buf_size];
+  msg_line_buf_ = new char[line_buf_size];
+  status_line_buf_ = new char[line_buf_size];
   clock_limit = 0;
   clock_handler( 0 );
   Window_vector::init();
@@ -510,8 +509,10 @@ int Screen::width() { return width_; }
 int Screen::max_windows() { return height_ / Window::min_height; }
 
 
-char * Screen::line_buf( int * const sizep )
-  { *sizep = line_buf_size; return line_buf_; }
+char * Screen::msg_line_buf( int * const sizep )
+  { *sizep = line_buf_size; return msg_line_buf_; }
+char * Screen::status_line_buf( int * const sizep )
+  { *sizep = line_buf_size; return status_line_buf_; }
 
 
 //void Screen::beep() { ::beep(); wrefresh( stdscr ); }
@@ -540,8 +541,7 @@ extern "C" void Screen::clock_handler( int sig )
       clock_string_[4] = ( t->tm_min % 10 ) + '0';
       }
     }
-  if( blink ) clock_string_[2] = ( clock_string_[2] != ':' ) ? ':' : ' ';
-  if( sig && ( time_change || blink ) )
+  if( sig && time_change )
     {
     Point old_cursor; save_cursor( old_cursor );
     if( clock_limit == 1 )
@@ -564,7 +564,6 @@ int Screen::kbhit() { return read_key( false, false ); }
 
 
 /* Wait for a keystroke. Return -1 if no key is available.
-   The clock only blinks when waiting here for a keystroke.
    The screen is mainly refreshed here (and in clock_handler).
    This function is the real "main loop" of the program.
 */
@@ -626,7 +625,7 @@ long Screen::get_string( const std::string & prompt,
                    scol += name.size() - namelen; modified = true;
                    s.erase( prompt.size(), namelen );
                    if( s.size() > prompt.size() && name.size() &&
-                       s[prompt.size()] == '/' && name[name.size()-1] == '/' )
+                       s[prompt.size()] == '/' && name.end()[-1] == '/' )
                      name.erase( name.size() - 1 );
                    s.insert( prompt.size(), name );
                    }
