@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2024 Antonio Diaz Diaz.
+   Copyright (C) 2005-2025 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -28,7 +28,8 @@ int max_windows();
 
 // return pointer to an array width() + 1 bytes in size
 //
-char * line_buf( int * const sizep );
+char * msg_line_buf( int * const sizep );
+char * status_line_buf( int * const sizep );
 
 //void beep();
 
@@ -39,7 +40,6 @@ extern "C" void clock_handler( int sig );	// update the clock
 int kbhit();		// Read key. Return -1 if no key is available.
 
 /* Wait for a keystroke. Return -1 if no key is available.
-   The clock only blinks when waiting here for a keystroke.
    The screen is mainly refreshed here (and in clock_handler).
    This function is the real "main loop" of the program.
 */
