@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2024 Antonio Diaz Diaz.
+   Copyright (C) 2005-2025 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -199,7 +199,7 @@ const char * Window::goto_mark( const int i )
     else
       {
       int bufsize = 0;
-      char * const buf = Screen::line_buf( &bufsize );
+      char * const buf = Screen::msg_line_buf( &bufsize );
       snprintf( buf, bufsize, "Mark %d not set", i );
       return buf;
       }
@@ -328,7 +328,7 @@ const char * Window::extend_marks()
   if( c > 0 )
     {
     int bufsize = 0;
-    char * const buf = Screen::line_buf( &bufsize );
+    char * const buf = Screen::msg_line_buf( &bufsize );
     snprintf( buf, bufsize, "%d new mark(s) set", c );
     return buf;
     }
@@ -342,7 +342,7 @@ const char * Window::set_mark( const int i )
     {
     bhp->buffer().mark[i] = bhp->pointer;
     int bufsize = 0;
-    char * const buf = Screen::line_buf( &bufsize );
+    char * const buf = Screen::msg_line_buf( &bufsize );
     snprintf( buf, bufsize, "Mark %d set", i );
     return buf;
     }
@@ -364,7 +364,7 @@ const char * Window::show_character_info() const
   const Buffer & buffer = bhp->buffer();
   const Point p = bhp->pointer;
   int bufsize = 0;
-  char * const buf = Screen::line_buf( &bufsize );
+  char * const buf = Screen::msg_line_buf( &bufsize );
   const int ch = buffer[p];
 
   if( ch < 0 && p != buffer.eof() )
@@ -393,7 +393,7 @@ const char * Window::show_multichar_value( const int size, const bool big_endian
   const Buffer & buffer = bhp->buffer();
   const Point p = bhp->pointer;
   int bufsize = 0;
-  char * const buf = Screen::line_buf( &bufsize );
+  char * const buf = Screen::msg_line_buf( &bufsize );
   if( size < 2 || size > 8 )
     {
     snprintf( buf, bufsize, "*** Error: Bad Multichar Size: %d", size );
@@ -446,7 +446,7 @@ const char * Window::show_utf8_code()
     }
 
   int bufsize = 0;
-  char * const buf = Screen::line_buf( &bufsize );
+  char * const buf = Screen::msg_line_buf( &bufsize );
   if( code >= 0 )
     {
     if( p != bhp->pointer ) update_points( p );
@@ -473,7 +473,7 @@ void Window::show_status_line( const char * const prefix ) const
   const Buffer_handle & bh = *bhp;
   const Buffer & buffer = bh.buffer();
   int bufsize = 0;
-  char * const buf = Screen::line_buf( &bufsize );
+  char * const buf = Screen::status_line_buf( &bufsize );
   int offset = bufsize - 41;
   const long line = bh.pcursor.line + 1, col = bh.pcursor.col + 1;
   for( long i = line; i > 9999; i /= 10 ) --offset;
