@@ -1,5 +1,5 @@
 /* GNU moe - My Own Editor
-   Copyright (C) 2005-2024 Antonio Diaz Diaz.
+   Copyright (C) 2005-2025 Antonio Diaz Diaz.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -50,7 +50,7 @@ const char * already_being_edited( const std::string & name,
           bufferp != &Bufhandle_vector::handle( i ).buffer() )
         {
         int bufsize = 0;
-        char * const buf = Screen::line_buf( &bufsize );
+        char * const buf = Screen::msg_line_buf( &bufsize );
         snprintf( buf, bufsize, "File '%s' is already being edited",
                   Screen::cut_filename( name, 31 ) );
         return buf;
@@ -93,13 +93,14 @@ bool read_only( const Buffer & buffer )
   }
 
 
-void replace_and_repaint( Buffer & buffer, const Basic_buffer & tmp )
+void replace_and_repaint( const Basic_buffer & tmp )
   {
+  Buffer & buffer = *Block::bufferp();
   Point p = Block::end();
   buffer.reset_appendable();
   buffer.replace( Block::begin(), p, tmp, tmp.bof(), tmp.eof() );
   buffer.reset_appendable();
-  if( RC::editor_options().auto_unmark ) Block::reset();
+  if( RC::editor_options().auto_unmark ) Block::unmark();
   else Block::set_end( buffer, p );
   Screen::repaint( &buffer );
   }
@@ -255,11 +256,7 @@ bool deescapize_string( const std::string & in, std::string & out,
 } // end namespace Window_vector
 
 
-int Window_vector::init()
-  {
-  curwin_ = 0;
-  return load( RC::editor_options().orphan_extra ? 1 : Bufhandle_vector::handles() );
-  }
+int Window_vector::init() { curwin_ = 0; return load( 1 ); }
 
 
 Window & Window_vector::curwin() { return data[curwin_]; }
@@ -370,7 +367,7 @@ const char * Window_vector::save_file( const int abort_key )
     {
     Screen::show_status_lines( &buffer );	// update modified status
     int bufsize = 0;
-    char * const buf = Screen::line_buf( &bufsize );
+    char * const buf = Screen::msg_line_buf( &bufsize );
     snprintf( buf, bufsize, "File '%s' saved",
               Screen::cut_filename( name, 13 ) );
     return buf;
@@ -425,12 +422,9 @@ int Window_vector::close( bool abort, const bool quiet )
 
 int Window_vector::close_and_exit( const bool abort )
   {
-  int key;
-  if( abort )
-    key = Screen::show_message( "Are you sure you want to abort ? (y/N) ",
-                                true, true );
-  else key = Screen::show_message( "Are you sure you want to exit ? (y/N) ",
-                                   true, true );
+  const int key = Screen::show_message( abort ?
+                  "Are you sure you want to abort ? (y/N) " :
+                  "Are you sure you want to exit ? (y/N) ", true, true );
   if( key == 'y' || key == 'Y' )
     {
     if( !abort )			// save all modified buffers
@@ -503,16 +497,19 @@ const char * Window_vector::add_char( const int key, const bool force )
 
   if( key >= 0 && key < 256 &&
       ( force || key == '\t' || key == '\n' || ISO_8859::isprint( key ) ) )
-    { if( w.buffer().pputc( w.pointer(), key ) )
-        Screen::repaint( &w.buffer() ); }
-  else
     {
-    int bufsize = 0;
-    char * const buf = Screen::line_buf( &bufsize );
-    snprintf( buf, bufsize, "Key code %d(0x%02X) ignored", key, key );
-    return buf;
+    const long col = w.pointer().col;
+    if( w.buffer().pputc( w.pointer(), key ) )
+      {
+      if( w.pointer().col < col ) w.to_left();		// pointer wrapped
+      Screen::repaint( &w.buffer() );
+      }
+    return 0;
     }
-  return 0;
+  int bufsize = 0;
+  char * const buf = Screen::msg_line_buf( &bufsize );
+  snprintf( buf, bufsize, "Key code %d(0x%02X) ignored", key, key );
+  return buf;
   }
 
 
@@ -620,11 +617,11 @@ const char * Window_vector::write_block()
       }
     if( !done ) return "Block not written";
     if( RC::editor_options().auto_unmark )
-      { Block::reset(); Screen::repaint( &buffer ); }
+      { Block::unmark(); Screen::repaint( &buffer ); }
     }
   catch( Buffer::Error & e ) { return e.msg; }
   int bufsize = 0;
-  char * const buf = Screen::line_buf( &bufsize );
+  char * const buf = Screen::msg_line_buf( &bufsize );
   snprintf( buf, bufsize, "Block written to file '%s'",
             Screen::cut_filename( name, 24 ) );
   return buf;
@@ -656,7 +653,7 @@ void Window_vector::indent_block()
     }
   buffer.reset_appendable();
   buffer.options.overwrite = ow;
-  if( RC::editor_options().auto_unmark ) Block::reset();
+  if( RC::editor_options().auto_unmark ) Block::unmark();
   Screen::repaint( &buffer );
   }
 
@@ -708,7 +705,7 @@ const char * Window_vector::unindent_block()
     }
   buffer.reset_appendable();
   buffer.options.overwrite = ow;
-  if( RC::editor_options().auto_unmark ) Block::reset();
+  if( RC::editor_options().auto_unmark ) Block::unmark();
   Screen::repaint( &buffer );
   return 0;
   }
@@ -826,7 +823,7 @@ const char * Window_vector::reformat_block()
       cursor.line = buffer.eop( cursor ).line;	// end of paragraph, keep col
       }
   if( change && !msg ) cursor.line = buffer.bop( Block::begin() ).line;
-  if( RC::editor_options().auto_unmark ) Block::reset();
+  if( RC::editor_options().auto_unmark ) Block::unmark();
   if( change )
     {
     buffer.reset_appendable();
@@ -876,7 +873,7 @@ const char * Window_vector::change_case( const int caps_level )
     tmp.pputc( p, ch );
     }
   if( !change ) return "No letters to change in block";
-  replace_and_repaint( buffer, tmp );
+  replace_and_repaint( tmp );
   return 0;
   }
 
@@ -899,7 +896,7 @@ void Window_vector::encode_base64()
     if( ++c >= 76 ) { c = 0; tmp.pputc( p, '\n' ); }
     }
   if( c ) tmp.pputc( p, '\n' );
-  replace_and_repaint( buffer, tmp );
+  replace_and_repaint( tmp );
   }
 
 
@@ -926,7 +923,7 @@ const char * Window_vector::decode_base64()
   Point p = tmp.bof();
   for( unsigned long i = 0; i < out.size(); ++i )
     tmp.pputc( p, out[i] );
-  replace_and_repaint( buffer, tmp );
+  replace_and_repaint( tmp );
   return 0;
   }
 
@@ -948,7 +945,7 @@ bool Window_vector::encode_ascii_utf8( const char ** const msgp,
   Point p = tmp.bof();
   for( unsigned long i = 0; i < out.size(); ++i )
     tmp.pputc( p, out[i] );
-  replace_and_repaint( buffer, tmp );
+  replace_and_repaint( tmp );
   *msgp = "Done";
   return true;
   }
@@ -988,7 +985,7 @@ const char * Window_vector::decode_quoted_printable_utf8( const bool mode_q,
       if( ret > 0 )
         {
         int bufsize = 0;
-        char * const buf = Screen::line_buf( &bufsize );
+        char * const buf = Screen::msg_line_buf( &bufsize );
         snprintf( buf, bufsize, "UTF-8 code 'U%04X' out of range in block", ret );
         return buf;
         }
@@ -1001,7 +998,7 @@ const char * Window_vector::decode_quoted_printable_utf8( const bool mode_q,
   Point p = tmp.bof();
   for( unsigned long i = 0; i < out.size(); ++i )
     tmp.pputc( p, out[i] );
-  replace_and_repaint( buffer, tmp );
+  replace_and_repaint( tmp );
   return "Done";
   }
 
@@ -1029,7 +1026,7 @@ const char * Window_vector::remove_utf8_out_of_range()
   Point p = tmp.bof();
   for( unsigned long i = 0; i < out.size(); ++i )
     tmp.pputc( p, out[i] );
-  replace_and_repaint( buffer, tmp );
+  replace_and_repaint( tmp );
   return "Done";
   }
 
@@ -1048,7 +1045,7 @@ void Window_vector::encode_rot1347( const bool mode13 )
   else
     for( Point p1 = Block::begin(); p1 < Block::end(); )
       tmp.pputc( p, Encoding::rot47( buffer.pgetc( p1 ) ) );
-  replace_and_repaint( buffer, tmp );
+  replace_and_repaint( tmp );
   }
 
 
@@ -1093,7 +1090,7 @@ const char * Window_vector::remove_duplicate_lines( const bool back )
     if( back ) w.update_points( Block::end(), true, true );
     else w.update_points( Block::begin(), true, true );
     }
-  if( RC::editor_options().auto_unmark ) Block::reset();
+  if( RC::editor_options().auto_unmark ) Block::unmark();
   Screen::repaint( &buffer );
   return 0;
   }
@@ -1373,7 +1370,7 @@ const char * Window_vector::search( const int abort_key, const bool again,
         }
       ++i; Block::restore_block_position();
       if( ask || found ) Screen::repaint( &w.buffer() );
-      feedback = !block;
+      feedback = true;
       continue;
       }
 
